@@ -135,7 +135,11 @@ class GitMixin:
         :rtype: bool
         """
 
-        if config.repo and not config.settings.dry_run:
+        if (
+            config.repo
+            and not config.settings.dry_run
+            or not config.settings.allow_push
+        ):
             branch: str = config.settings.git_branch_name
             logging.info("Pushing changes to %s", branch)
             config.repo.remotes.origin.push(branch)  # pylint: disable=no-member
